==> mingw-w64-starpu-1.4.5-2.src.tar.zst: starpu-1.4.5/doc/doxygen_web_installation/html_web_installation/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Installation", "index.html", [
    [ "Building and Installing StarPU", "BuildingAndInstallingStarPU.html", [
      [ "Installing a Binary Package", "BuildingAndInstallingStarPU.html#InstallingABinaryPackage", null ],
      [ "Installing a Source Package", "BuildingAndInstallingStarPU.html#InstallingASourcePackage", [
        [ "Installing the Spack Package", "BuildingAndInstallingStarPU.html#SpackInstallation", null ],
        [ "Using a Module", "BuildingAndInstallingStarPU.html#UsingModule", null ]
      ] ],
      [ "Building from Source", "BuildingAndInstallingStarPU.html#InstallingFromSource", [
        [ "Optional Dependencies", "BuildingAndInstallingStarPU.html#OptionalDependencies", null ],
        [ "Getting Sources", "BuildingAndInstallingStarPU.html#GettingSources", null ],
        [ "Configuring StarPU", "BuildingAndInstallingStarPU.html#ConfiguringStarPU", null ],
        [ "Building StarPU", "BuildingAndInstallingStarPU.html#BuildingStarPU", null ],
        [ "Installing StarPU", "BuildingAndInstallingStarPU.html#InstallingStarPU", null ]
      ] ]
    ] ],
    [ "Compilation Configuration", "CompilationConfiguration.html", [
      [ "Common Configuration", "CompilationConfiguration.html#CommonConfiguration", null ],
      [ "Configuring Workers", "CompilationConfiguration.html#ConfiguringWorkers", null ],
      [ "Extension Configuration", "CompilationConfiguration.html#ExtensionConfiguration", null ],
      [ "Advanced Configuration", "CompilationConfiguration.html#AdvancedConfiguration", null ]
    ] ],
    [ "Execution Configuration Through Environment Variables", "ExecutionConfigurationThroughEnvironmentVariables.html", [
      [ "Configuring Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#EnvConfiguringWorkers", [
        [ "General Configuration", "ExecutionConfigurationThroughEnvironmentVariables.html#Basic", null ],
        [ "CPU Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#cpuWorkers", null ],
        [ "CUDA Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#cudaWorkers", null ],
        [ "OpenCL Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#openclWorkers", null ],
        [ "Maxeler FPGA Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#maxfpgaWorkers", null ],
        [ "MPI Master Slave Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#mpimsWorkers", null ],
        [ "TCP/IP Master Slave Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#tcpipmsWorkers", null ],
        [ "HIP Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#hipWorkers", null ],
        [ "MPI Configuration", "ExecutionConfigurationThroughEnvironmentVariables.html#mpiConf", null ]
      ] ],
      [ "Configuring The Scheduling Engine", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheSchedulingEngine", null ],
      [ "Configuring The Heteroprio Scheduler", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringHeteroprio", [
        [ "Configuring LAHeteroprio", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringLaHeteroprio", null ],
        [ "Configuring AutoHeteroprio", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringAutoHeteroprio", null ]
      ] ],
      [ "Extensions", "ExecutionConfigurationThroughEnvironmentVariables.html#Extensions", null ],
      [ "Miscellaneous And Debug", "ExecutionConfigurationThroughEnvironmentVariables.html#MiscellaneousAndDebug", null ],
      [ "Configuring The Hypervisor", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheHypervisor", null ]
    ] ],
    [ "Configuration and Initialization", "ConfigurationAndInitialization.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BuildingAndInstallingStarPU.html",
"group__API__Codelet__And__Tasks.html#ad6dfcbb8bb86ca8ce0678b4b10bf853b",
"group__API__Data__Interfaces.html#ae039cff4622424d30f99811665f4de4f",
"group__API__Data__Interfaces.html#structstarpu__ndim__interface",
"group__API__HIP__Extensions.html#gad40f30899d319b57afe87e9f11e873e6",
"group__API__MPI__Support.html#ga234e28905c976ed1b03fcdf75812a06d",
"group__API__OpenCL__Extensions.html#a685357d9709ece920bf269a917ed8297",
"group__API__Perf__Monitoring.html#ga247ff710854bfd7e3ab976b2ebad478e",
"group__API__Running__Drivers.html#a50af396b52e8c54e4e3b23803105fc0e",
"group__API__Scheduling__Policy.html#ga98ec28ae7ac484959f48b7a79372c1af",
"group__API__Workers.html#gab568e2368c11f9fb362f04264ad4cd04",
"interfacefstarpu__mod_1_1fstarpu__data__request__allocation.html",
"interfacefstarpu__mod_1_1fstarpu__tag__wait.html",
"sc__hypervisor__monitoring_8h.html#a063487ad1a8059812b5c4f721bf828f6"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> mingw-w64-starpu-1.4.8-1.src.tar.zst: starpu-1.4.8/doc/doxygen_web_installation/html_web_installation/navtreedata.js <==
/*
 @licstart  The following is the entire license notice for the JavaScript code in this file.

 The MIT License (MIT)

 Copyright (C) 1997-2020 by Dimitri van Heesch

 Permission is hereby granted, free of charge, to any person obtaining a copy of this software
 and associated documentation files (the "Software"), to deal in the Software without restriction,
 including without limitation the rights to use, copy, modify, merge, publish, distribute,
 sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in all copies or
 substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING
 BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM,
 DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.

 @licend  The above is the entire license notice for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "StarPU Handbook - StarPU Installation", "index.html", [
    [ "Building and Installing StarPU", "BuildingAndInstallingStarPU.html", [
      [ "Installing a Binary Package", "BuildingAndInstallingStarPU.html#InstallingABinaryPackage", null ],
      [ "Installing a Source Package", "BuildingAndInstallingStarPU.html#InstallingASourcePackage", [
        [ "Installing the Spack Package", "BuildingAndInstallingStarPU.html#SpackInstallation", null ],
        [ "Using a Module", "BuildingAndInstallingStarPU.html#UsingModule", null ]
      ] ],
      [ "Building from Source", "BuildingAndInstallingStarPU.html#InstallingFromSource", [
        [ "Optional Dependencies", "BuildingAndInstallingStarPU.html#OptionalDependencies", null ],
        [ "Getting Sources", "BuildingAndInstallingStarPU.html#GettingSources", null ],
        [ "Configuring StarPU", "BuildingAndInstallingStarPU.html#ConfiguringStarPU", null ],
        [ "Building StarPU", "BuildingAndInstallingStarPU.html#BuildingStarPU", null ],
        [ "Installing StarPU", "BuildingAndInstallingStarPU.html#InstallingStarPU", null ]
      ] ]
    ] ],
    [ "Compilation Configuration", "CompilationConfiguration.html", [
      [ "Common Configuration", "CompilationConfiguration.html#CommonConfiguration", null ],
      [ "Configuring Workers", "CompilationConfiguration.html#ConfiguringWorkers", null ],
      [ "Extension Configuration", "CompilationConfiguration.html#ExtensionConfiguration", null ],
      [ "Advanced Configuration", "CompilationConfiguration.html#AdvancedConfiguration", null ]
    ] ],
    [ "Execution Configuration Through Environment Variables", "ExecutionConfigurationThroughEnvironmentVariables.html", [
      [ "Configuring Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#EnvConfiguringWorkers", [
        [ "General Configuration", "ExecutionConfigurationThroughEnvironmentVariables.html#Basic", null ],
        [ "CPU Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#cpuWorkers", null ],
        [ "CUDA Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#cudaWorkers", null ],
        [ "OpenCL Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#openclWorkers", null ],
        [ "Maxeler FPGA Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#maxfpgaWorkers", null ],
        [ "MPI Master Slave Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#mpimsWorkers", null ],
        [ "TCP/IP Master Slave Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#tcpipmsWorkers", null ],
        [ "HIP Workers", "ExecutionConfigurationThroughEnvironmentVariables.html#hipWorkers", null ],
        [ "MPI Configuration", "ExecutionConfigurationThroughEnvironmentVariables.html#mpiConf", null ]
      ] ],
      [ "Configuring The Scheduling Engine", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheSchedulingEngine", null ],
      [ "Configuring The Heteroprio Scheduler", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringHeteroprio", [
        [ "Configuring LAHeteroprio", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringLaHeteroprio", null ],
        [ "Configuring AutoHeteroprio", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringAutoHeteroprio", null ]
      ] ],
      [ "Extensions", "ExecutionConfigurationThroughEnvironmentVariables.html#Extensions", null ],
      [ "Miscellaneous And Debug", "ExecutionConfigurationThroughEnvironmentVariables.html#MiscellaneousAndDebug", null ],
      [ "Configuring The Hypervisor", "ExecutionConfigurationThroughEnvironmentVariables.html#ConfiguringTheHypervisor", null ]
    ] ],
    [ "Configuration and Initialization", "ConfigurationAndInitialization.html", null ],
    [ "The GNU Free Documentation License", "GNUFreeDocumentationLicense.html", [
      [ "ADDENDUM: How to use this License for your documents", "GNUFreeDocumentationLicense.html#ADDENDUM", null ]
    ] ],
    [ "", "Files.html", null ],
    [ "Deprecated List", "deprecated.html", null ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ]
    ] ],
    [ "Data Structures", "annotated.html", [
      [ "Data Structures", "annotated.html", "annotated_dup" ],
      [ "Data Structure Index", "classes.html", null ],
      [ "Data Fields", "functions.html", [
        [ "All", "functions.html", "functions_dup" ],
        [ "Variables", "functions_vars.html", "functions_vars" ]
      ] ]
    ] ],
    [ "Files", "files.html", [
      [ "File List", "files.html", "files_dup" ],
      [ "Globals", "globals.html", [
        [ "All", "globals.html", "globals_dup" ],
        [ "Functions", "globals_func.html", "globals_func" ],
        [ "Variables", "globals_vars.html", null ],
        [ "Typedefs", "globals_type.html", null ],
        [ "Enumerations", "globals_enum.html", null ],
        [ "Enumerator", "globals_eval.html", null ],
        [ "Macros", "globals_defs.html", "globals_defs" ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"BuildingAndInstallingStarPU.html",
"group__API__Codelet__And__Tasks.html#ad4b215b1fc4ae0fc29c98cf8a26029c7",
"group__API__Data__Interfaces.html#adf548c64da75d9ba392aec9f6cbb8884",
"group__API__Data__Interfaces.html#structstarpu__multiformat__data__interface__ops",
"group__API__HIP__Extensions.html#ga81c617c18f5cc3e4799fd6858e5c6d3f",
"group__API__MPI__Support.html#ga0ec1ce958654468b20224c9ae772f98f",
"group__API__Modularized__Scheduler.html#structstarpu__sched__component__mct__data",
"group__API__Perf__Monitoring.html#ga000af6e254ec5a3e95868f50d354f693",
"group__API__Profiling__Tool.html#structstarpu__prof__tool__api__info",
"group__API__Scheduling__Policy.html#ga8004f14208fd9b29f36440dc11ca765b",
"group__API__Workers.html#ga9b2541fc1a20c4c486c499af01a3283c",
"interfacefstarpu__mod_1_1fstarpu__data__prefetch__on__node__prio.html",
"interfacefstarpu__mod_1_1fstarpu__tag__get__task.html",
"sc__hypervisor__config_8h.html#ac56775b3eafc46d10aaf2162676b72d0"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
